(release-3006.16)=
# Salt 3006.16 release notes

<!---
Do not edit this file. This is auto generated.
Edit the templates in doc/topics/releases/templates/
for a given release.
-->


<!--
Add release specific details below
-->

<!--
Do not edit the changelog below.
This is auto generated.
-->
## Changelog

### Fixed

- Fixed an issue with the win_network salt.util to select interfaces
  by name instead of description. [#58138](https://github.com/saltstack/salt/issues/58138)
- Fixes debug logging for master AES and session keys to be consistent across crypt.AsyncAuth._authenticate() and crypt.SAuth.authenticate(). Now differentiates between master key rotation and session key rotation. [#68113](https://github.com/saltstack/salt/issues/68113)
- Fix potential race conditions an memory usage in zeromq request client
  tranport. [#68297](https://github.com/saltstack/salt/issues/68297)
- Revert change to store cargo home as a temporary directory [#68311](https://github.com/saltstack/salt/issues/68311)
- Update openssl FIPS provider to 3.1.2 (certified until 2030) [#68317](https://github.com/saltstack/salt/issues/68317)


### Added

- Added the ability to pass the context to pyobjects renderer [#68224](https://github.com/saltstack/salt/issues/68224)
